Authors
=======
The following have contributed to the development, maintenance, and testing of the core Bio2BEL.

Maintainer
----------
`Charles Tapley Hoyt <https://github.com/cthoyt>`_

Contributors
------------
- `Daniel Domingo-Fernández <https://github.com/ddomingof>`_
- `Ben Gyori <https://github.com/bgyori>`_
- `John Bachman <https://github.com/johnbachman>`_
- `Bruce Schultz <https://github.com/brucetony>`_
- `Sophia Krix <https://github.com/sophiakrix>`_
